=======
History
=======

2019.02.3 (2019-02-20)
----------------------

* Adding SetNamer naming

2019.02.2 (2019-02-18)
----------------------

* Adding process limit for subprocess dispatching
* Adding RandomSweep sweep type
* Adding HashNamer naming
* Clarifying version dependencies
* More examples

2019.02 (2019-02-07)
--------------------

* Separating sweep logic into a separate module
* Adding FilteredCartesianSweep sweep type
* Numerous documentation changes, including many more examples

2019.01 (2019-01-21)
--------------------

* First release on PyPI
